from distutils.core import setup
setup(
name = 'tuhin00',
version = '1.0.0',
py_modules = ['looperr'],
author = 'aa t',
author_email = 't@gd.comm',
url = 'http://www.headfirstlabs.com',
description = 'A simple LOOpER',
)
